@@ -22,7 +22,7 @@ file()
 	addr_t addr;
 	extern const char head_file[];
 
-	while ((c = getopt(argcnt, args, "f")) != EOF) {
+	while ((c = getopt(argcnt, args, "")) != EOF) {
 		switch (c) {
 		case 'f':
 			full = 1;
