@@ -57,7 +57,7 @@ int full;
 		vg.pv_max, vg.pv_cur, vg.pv_act);
 	mprintf(" %4x %5x %5x %5x ",
 		vg.vgda, vg.pe_size, vg.pe_total, vg.pe_allocated);
-	mprint_str(vg.vg_name, NAME_LEN);
+	mprintstr(vg.vg_name, NAME_LEN);
 	mprintbit(vgaccess, vg.vg_access);
 	mprintbit(vgstatus, vg.vg_status);
 	mprintf("\n");
@@ -91,35 +91,35 @@ int full;
 	memread(addr, sizeof(pv), &pv, "pv");
 	if (full == 2) {
 		mprintf(FPTR " ", addr);
-		print_kdev_t(pv.pv_dev);
+		mprint_kdev_t(pv.pv_dev);
 		mprintf(" %8x ", pv.pv_size);
-		mprint_str(pv.pv_name, NAME_LEN);
+		mprintstr(pv.pv_name, NAME_LEN);
 		mprintf("\n");
 		return 0;
 	}
 
 	mprintf("id:  %02x%02x\n", pv.id[0], pv.id[1]);
 	mprintf("version:  %04x\n", pv.version);
-	mprintf("pv_name:  "); mprint_str(pv.pv_name, NAME_LEN); mprintf("\n");
-	mprintf("vg_name:  "); mprint_str(pv.vg_name, NAME_LEN); mprintf("\n");
-	mprintf("system_id:  "); mprint_str(pv.system_id, NAME_LEN); mprintf("\n");
+	mprintf("pv_name:  "); mprintstr(pv.pv_name, NAME_LEN); mprintf("\n");
+	mprintf("vg_name:  "); mprintstr(pv.vg_name, NAME_LEN); mprintf("\n");
+	mprintf("system_id:  "); mprintstr(pv.system_id, NAME_LEN); mprintf("\n");
 	mprintf("pv_dev: %04x\n", pv.pv_dev);
 	mprintf("pv_number: %x\n", pv.pv_number);
-        mprintf("pv_status: %x\n", pv.pv_status);
-        mprintf("pv_allocatable: %x\n", pv.pv_allocatable);
-        mprintf("pv_size: %x\n", pv.pv_size);
-        mprintf("lv_cur: %x\n", pv.lv_cur);
-        mprintf("pe_size: %x\n", pv.pe_size);
-        mprintf("pe_total: %x\n", pv.pe_total);
-        mprintf("pe_allocated: %x\n", pv.pe_allocated);
-        mprintf("pe_stale: %x\n", pv.pe_stale);
-        mprintf("pe: %08lx\n", pv.pe);
+	mprintf("pv_status: %x\n", pv.pv_status);
+	mprintf("pv_allocatable: %x\n", pv.pv_allocatable);
+	mprintf("pv_size: %x\n", pv.pv_size);
+	mprintf("lv_cur: %x\n", pv.lv_cur);
+	mprintf("pe_size: %x\n", pv.pe_size);
+	mprintf("pe_total: %x\n", pv.pe_total);
+	mprintf("pe_allocated: %x\n", pv.pe_allocated);
+	mprintf("pe_stale: %x\n", pv.pe_stale);
+	mprintf("pe: %08lx\n", pv.pe);
 #if SUBLEVEL>=15
 	mprintf("bd: " FPTR "\n", pv.bd);
 #else
 	mprintf("inode:  " FPTR "\n", pv.inode);
 #endif
-	mprintf("pv_uuid:  "); mprint_str(pv.pv_uuid, UUID_LEN + 1); mprintf("\n");
+	mprintf("pv_uuid:  "); mprintstr(pv.pv_uuid, UUID_LEN + 1); mprintf("\n");
 	return 0;
 }
 
@@ -134,16 +134,16 @@ int full;
 	if (full == 2) {
 		mprintf(FPTR " ", addr);
 		mprintf(" %2x %2x %2x", lv.lv_access, lv.lv_status, lv.lv_open);
-		print_kdev_t(lv.lv_dev);
+		mprint_kdev_t(lv.lv_dev);
 		mprintf(" %2x ", lv.lv_number);
 		mprintf("%8x ", lv.lv_size);
-		mprint_str(lv.lv_name, NAME_LEN);
+		mprintstr(lv.lv_name, NAME_LEN);
 		mprintf("\n");
 		return 0;
 	}
 
-	mprintf("lv_name:   "); mprint_str(lv.lv_name, NAME_LEN); mprintf("\n");
-	mprintf("vg_name:   "); mprint_str(lv.vg_name, NAME_LEN); mprintf("\n");
+	mprintf("lv_name:   "); mprintstr(lv.lv_name, NAME_LEN); mprintf("\n");
+	mprintf("vg_name:   "); mprintstr(lv.vg_name, NAME_LEN); mprintf("\n");
 	mprintf("access:    %x\n", lv.lv_access);
 	mprintf("status:    %x\n", lv.lv_status);
 	mprintf("open:      %x\n", lv.lv_open);
