@@ -37,7 +37,7 @@ print_files_struct(addr)
 	mprintf("%3x %5d %5d %5d", ATOMIC_READ(files.count), files.max_fds, files.max_fdset, files.next_fd);
 	mprintf(" " FPTR " " FPTR " " FPTR "\n", files.fd, files.close_on_exec, files.open_fds);
 	if ((addr_t)files.fd == addr + OFFSET(struct files_struct, fd_array))
-		memcpy(fds, files.fd_array, sizeof(files.fd_array));
+		m_memcpy(fds, files.fd_array, sizeof(files.fd_array));
 	else
 		memread((addr_t)files.fd, sizeof(fds), &fds, "file");
 	if ((addr_t)files.close_on_exec == addr + OFFSET(struct files_struct, close_on_exec_init))
@@ -267,6 +267,12 @@ getinfo_fromtask(addr, ip, sp, stack)
 		*ip = 0;
 	if (sp)
 		*sp = tsk.thread.ksp;
+#else
+#if defined(ARCH_x86_64)
+	if (ip)
+		*ip = 0;
+	if (sp)
+		*sp = tsk.thread.rsp;
 #else
 	/* others */
 	if (ip)
@@ -274,6 +280,7 @@ getinfo_fromtask(addr, ip, sp, stack)
 	if (sp)
 		*sp = 0;
 #endif
+#endif
 #endif
 	if (stack)
 		*stack = addr;
