@@ -13,6 +13,7 @@
 #include <linux/slab.h>
 #include <linux/vmalloc.h>
 #include <linux/socket.h>
+#include <asm/uaccess.h>
 #if defined(CONFIG_INET)
 #include <linux/in.h>
 #endif
@@ -41,6 +42,7 @@ struct sizetbl sizetbl[] = {
 	{ "caddr_t",		sizeof(caddr_t) },
 	{ "dentry",		sizeof(struct dentry) },
 	{ "dev_t",		sizeof(dev_t) },
+	{ "exception_table_entry", sizeof(struct exception_table_entry) },
 	{ "ext2_inode_info",	sizeof(struct ext2_inode_info) },
 	{ "ext2_sb_info",	sizeof(struct ext2_sb_info) },
 	{ "fd_set",		sizeof(fd_set) },
@@ -110,6 +112,7 @@ struct sizetbl sizetbl[] = {
 	{ "vm_area_struct",	sizeof(struct vm_area_struct) },
 	{ "vm_struct",		sizeof(struct vm_struct) },
 	{ "wait_queue_head_t",	sizeof(wait_queue_head_t) },
+	{ "wait_queue_t",	sizeof(wait_queue_t) },
 	{ "zone_t",		sizeof(zone_t) },
 };
 int sizetbl_size = sizeof(sizetbl) / sizeof(sizetbl[0]);
