@@ -133,6 +133,9 @@ print_file(addr, full)
 		mprintf("\towener.pid: %x\n", f.f_owner.pid);
 		mprintf("\tversion:    %lx\n", f.f_version);
 		mprintf("\tsecurity    " FPTR "\n", f.f_security);
+#ifdef _file_has_f_mapping
+		mprintf("\tmapping:    " FPTR "\n", f.f_mapping);
+#endif
 	}
 	return (addr_t)f.f_list.next;
 }
@@ -221,6 +224,7 @@ print_inode(addr, full)
 		else
 			mprintf("\n");
 		mprintf("\tfop:       " FPTR "  ", inode.i_fop);
+		p = getsymstr((addr_t)inode.i_fop);
 		if (p)
 			mprintf("(%s)\n", p);
 		else
@@ -236,6 +240,9 @@ print_inode(addr, full)
 		mprintf("\tstate:     %lx ", inode.i_state);
 		mprintbit(istate, inode.i_state);
 		mprintf("\n\tflags:     %x\n", inode.i_flags);
+#ifdef _inode_has_dirtied_when
+		mprintf("\tdirtied_when: %lx\n", inode.dirtied_when);
+#endif /*_inode_has_dirtied_when*/
 		mprintf("\tgen:       %u\n", inode.i_generation);
 		mprintf("\tgeneric_ip:" FPTR "\n", inode.u.generic_ip);
 		mprintf("\n");
@@ -439,44 +446,56 @@ print_address_space(addr, plist)
 #define ISEMPTY(list) \
 	((addr_t)as.list.next == addr + OFFSET(struct address_space, list))
 
+#ifdef _address_space_has_clean_pages
 	mprintf("clean_pages:  ");
 	if (ISEMPTY(clean_pages))
 		mprintf(SPTR "  " SPTR "\n", "-", "-");
 	else
 		mprintf(FPTR "  " FPTR "\n",
 			as.clean_pages.next, as.clean_pages.prev);
+#endif
 
+#ifdef _address_space_has_dirty_pages
 	mprintf("dirty_pages:  ");
 	if (ISEMPTY(dirty_pages))
 		mprintf(SPTR "  " SPTR "\n", "-", "-");
 	else
 		mprintf(FPTR "  " FPTR "\n",
 			as.dirty_pages.next, as.dirty_pages.prev);
+#endif
 
+#ifdef _address_space_has_locked_pages
 	mprintf("locked_pages: ");
 	if (ISEMPTY(locked_pages))
 		mprintf(SPTR "  " SPTR "\n", "-", "-");
 	else
 		mprintf(FPTR "  " FPTR "\n",
 			as.locked_pages.next, as.locked_pages.prev);
+#endif
 
+#ifdef _address_space_has_io_pages
 	mprintf("io_pages:     ");
 	if (ISEMPTY(io_pages))
 		mprintf(SPTR "  " SPTR "\n", "-", "-");
 	else
 		mprintf(FPTR "  " FPTR "\n",
 			as.io_pages.next, as.io_pages.prev);
+#endif
+
+#ifdef _address_space_has_writeback_index
+	mprintf("writeback_index: %8lx\n", as.writeback_index);
+#endif
 
 	mprintf("nrpages:      %8lx\n", as.nrpages);
 	mprintf("ops:          " FPTR "\n", as.a_ops);
 	mprintf("host:         " FPTR "\n", as.host);
 	mprintf("mmap:         " FPTR "\n", as.i_mmap.next);
 	mprintf("mmap_shared:  " FPTR "\n", as.i_mmap_shared.next);
-	mprintf("dirty_when:   %lx\n", as.dirtied_when);
 	mprintf("gfp_mask:    ");
 	mprintbit(asflags, as.flags & ~__GFP_BITS_MASK);
 	print_gfp(as.flags & __GFP_BITS_MASK);
 
+#ifdef _address_space_has_clean_pages
 	if (plist & 1) {
 		prhead_page();
 		top = addr + OFFSET(struct address_space, clean_pages) - OFFSET(struct page, list);
@@ -485,6 +504,9 @@ print_address_space(addr, plist)
 			paddr = print_page(paddr, 1);
 		}
 	}
+#endif
+
+#ifdef _address_space_has_dirty_pages
 	if (plist & 2) {
 		prhead_page();
 		top = addr + OFFSET(struct address_space, dirty_pages) - OFFSET(struct page, list);
@@ -493,6 +515,9 @@ print_address_space(addr, plist)
 			paddr = print_page(paddr, 1);
 		}
 	}
+#endif
+
+#ifdef _address_space_has_locked_pages
 	if (plist & 4) {
 		prhead_page();
 		top = addr + OFFSET(struct address_space, locked_pages) - OFFSET(struct page, list);
@@ -501,6 +526,7 @@ print_address_space(addr, plist)
 			paddr = print_page(paddr, 1);
 		}
 	}
+#endif
 }
 
 void
