@@ -38,7 +38,7 @@ print_files_struct(addr)
 	mprintf("%3x %5d %5d %5d", ATOMIC_READ(files.count), files.max_fds, files.max_fdset, files.next_fd);
 	mprintf(" " FPTR " " FPTR " " FPTR "\n", files.fd, files.close_on_exec, files.open_fds);
 	if ((addr_t)files.fd == addr + OFFSET(struct files_struct, fd_array))
-		memcpy(fds, files.fd_array, sizeof(files.fd_array));
+		m_memcpy(fds, files.fd_array, sizeof(files.fd_array));
 	else
 		memread((addr_t)files.fd, sizeof(fds), &fds, "file");
 	if ((addr_t)files.close_on_exec == addr + OFFSET(struct files_struct, close_on_exec_init))
@@ -75,7 +75,7 @@ prhead_task(sw)
 	case 0:
 		p = "MM";	break;
 	case 1:
-		p = "TTY";	break;
+		p = "SIGNAL";	break;
 	case 2:
 		p = "FS";	break;
 	case 3:
@@ -115,12 +115,16 @@ print_task(addr, full)
 	case TASK_DEAD:			c = 'D';	break;
 	default:			c = '?';	break;
 	}
+#ifdef _task_struct_has_session
 	mprintf("%c %5d %5d %5d %5d ", c, ts.pid, ts.session, ts.uid, ts.euid);
+#else
+	mprintf("%c %5d %5d %5d %5d ", c, ts.pid, 0, ts.uid, ts.euid); /*XXX*/
+#endif
 	switch (saved_sw_task) {
 	default:
 		mprintf(FPTR, ts.mm);	break;
 	case 1:
-		mprintf(FPTR, ts.tty);	break;
+		mprintf(FPTR, ts.signal);	break;
 	case 2:
 		mprintf(FPTR, ts.fs);	break;
 	case 3:
@@ -153,7 +157,9 @@ print_task(addr, full)
 	mprintf("\tstart_time: %llx\n", ts.start_time);
 	mprintf("\tcap:        %x\n", ts.cap_effective);
 	mprintf("\tuser:       " FPTR "  (user_struct)\n", ts.user);
+#ifdef _task_struct_has_tty
 	mprintf("\ttty:        " FPTR "  (tty_struct)\n",  ts.tty);
+#endif
 	mprintf("\tfs:         " FPTR "  (fs_struct)\n",   ts.fs);
 	mprintf("\tnamespace:  " FPTR "  (namespace)\n",   ts.namespace);
 	mprintf("\tthread:     %lx\n", addr + OFFSET(struct task_struct, thread));
@@ -195,15 +201,22 @@ getinfo_fromtask(addr, ip, sp, stack)
 #else
 #if defined(ARCH_ia64) || defined(ARCH_ppc)
 	if (ip)
-		*ip = NULL;
+		*ip = 0;
 	if (sp)
 		*sp = tsk.thread.ksp;
+#else
+#if defined(ARCH_x86_64)
+	if (ip)
+		*ip = 0;
+	if (sp)
+		*sp = tsk.thread.rsp;
 #else
 	/* others */
 	if (ip)
-		*ip = NULL;
+		*ip = 0;
 	if (sp)
-		*sp = NULL;
+		*sp = 0;
+#endif
 #endif
 #endif
 	if (stack)
@@ -394,6 +407,12 @@ print_signal_struct(addr)
 	mprintf("%3x %3x " FPTR " %7x %3x",
 		sig.group_exit, sig.group_exit_code,
 		sig.group_exit_task, sig.notify_count, sig.group_stop_count);
+
+#ifdef _signal_struct_has_pgrp
+	mprintf("%5d %5d %5d %x " FPTR "\n",
+		sig.pgrp, sig.tty_old_pgrp, sig.session, sig.leader,
+		sig.tty);
+#endif
 	mprintf("\n");
 	return 0;
 }
