@@ -192,7 +192,7 @@ init_sym()
 	char type;
 	char buf[256];
 	int i, hash;
-	addr_t swapper_pg_dir;
+	addr_t swapper_pg_dir = 0;
 
 	if (symname == NULL) {
 		symname = "/boot/System.map";
@@ -556,3 +556,8 @@ m_ntohs(net)
 {
 	return ntohs(net);
 }
+
+void *m_memcpy(void *dest, const void *src, int n)
+{
+	return memcpy(dest, src, n);
+}
