@@ -122,9 +122,10 @@ print_xfs_inode(addr, fflag, rflag)
 }
 
 addr_t
-print_xfs_bmbt_rec(addr, size)
+print_xfs_bmbt_rec(addr, size, needswap)
 	addr_t addr;
 	int size;
+	int needswap;
 {
 	int i, n;
 	struct bmbt {
@@ -145,15 +146,17 @@ print_xfs_bmbt_rec(addr, size)
 			xfs_fileoff_t startoff;
 			xfs_fsblock_t startblock;
 			xfs_filblks_t blockcount;
-#if 1
-			/* new style */
-			__u64 l0 = bmbt[i].l0, l1 = bmbt[i].l1;
-#else
-			/* old fashon */
-			__u64 l0 = be64_to_cpup(&bmbt[i].l0);
-			__u64 l1 = be64_to_cpup(&bmbt[i].l1);
-#endif
+			__u64 l0, l1;
 
+			if (!needswap) {
+				/* new style */
+				l0 = bmbt[i].l0;
+				l1 = bmbt[i].l1;
+			} else {
+				/* old fashon */
+				l0 = be64_to_cpup(&bmbt[i].l0);
+				l1 = be64_to_cpup(&bmbt[i].l1);
+			}
 			mprintf(FPTR " ", addr);
 
 			ext_flag = l0 >> (64 - BMBT_EXNTFLAG_BITLEN);
