@@ -32,6 +32,10 @@
 
 #include "flags_pagebuf.h"
 
+#if defined(_xfs_buf_has_pb_flags) && !defined(_page_buf_s_has_pb_flags)
+typedef struct xfs_buf page_buf_t;
+#endif
+
 extern void prhead_semaphore();
 extern addr_t print_semaphore();
 
@@ -49,12 +53,12 @@ print_pagebuf(addr, fflag)
 {
 	page_buf_t pb;
 
-#ifdef _page_buf_s_has_pb_pin_count
-	memread(addr, sizeof(pb), &pb, "page_buf_t");
-#else
+#ifdef _page_buf_s_has_pb_common
 	page_buf_private_t pbp;
 	memread(addr, sizeof(pbp), &pbp, "page_buf_t");
 	pb = pbp.pb_common;
+#else
+	memread(addr, sizeof(pb), &pb, "page_buf_t");
 #endif
 
 	mprintf(FPTR " ", addr);
@@ -80,31 +84,31 @@ print_pagebuf(addr, fflag)
 		mprintf("  fspriv  " FPTR "\n", pb.pb_fspriv);
 		mprintf("  fspriv2 " FPTR "\n", pb.pb_fspriv2);
 		mprintf("  fspriv3 " FPTR "\n", pb.pb_fspriv3);
-#ifdef _page_buf_s_has_pb_pin_count
-		mprintf("  pin_count  %x\n", ATOMIC_READ(pb.pb_pin_count));
-#else
+#ifdef _page_buf_s_has_pb_common
 		mprintf("  pin_count  %x\n", pbp.pb_pin_count);
+#else
+		mprintf("  pin_count  %x\n", ATOMIC_READ(pb.pb_pin_count));
 #endif
 		mprintf("  sema:\n");
 		prhead_semaphore();
-#ifdef _page_buf_s_has_pb_sema
-		/* new style */
-		print_semaphore(addr + OFFSET(page_buf_t, pb_sema));
-#else
+#ifdef _page_buf_private_s_has_pb_sema
 		/* old fashion */
 		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_sema));
+#else
+		/* new style */
+		print_semaphore(addr + OFFSET(page_buf_t, pb_sema));
 #endif
 
 		mprintf("  iodonesema:\n");
 		prhead_semaphore();
-#ifdef _page_buf_s_has_pb_iodonesema
-		/* new style */
-		print_semaphore(addr + OFFSET(page_buf_t, pb_iodonesema));
-#else
+#ifdef _page_buf_private_s_has_pb_iodonesema
 		/* old fashion */
 		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_iodonesema));
 		/*struct page_buf_private_s priv;*/
 		/*memread(addr, sizeof(priv), &priv, "page_buf_private_t");*/
+#else
+		/* new style */
+		print_semaphore(addr + OFFSET(page_buf_t, pb_iodonesema));
 #endif
 	}
 
