@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -7,10 +7,13 @@
 
 PRIVATE addr_t pagebuf();
 const commandtable_t command_pagebuf =
-	{"page_buf", pagebuf, "[-af] address", "[XFS] print page_buf_t table\n  -a  follow next\n  -f  more detail"};
+	{"page_buf", pagebuf, "[-a] [-f] [address]", "[XFS] print page_buf_t table\n  -a  follow next\n  -f  more detail"};
 
 extern void prhead_pagebuf();
 extern addr_t print_pagebuf();
+extern void print_all_pagebuf();
+
+addr_t pbhash_addr;
 
 PRIVATE addr_t
 pagebuf()
@@ -41,7 +44,8 @@ pagebuf()
 			} while (aflag && addr && start != addr);
 		}
 	} else {
-		THROW(usage);
+		GETADDR(pbhash);
+		print_all_pagebuf(pbhash_addr, fflag);
 	}
 	return addr;
 }
