@@ -6,6 +6,7 @@ extern const commandtable_t
 	command_xfs_inode,
 	command_xfs_log_item,
 	command_xfs_mount,
+	command_xfs_perag,
 	command_xfs_trans,
 	command_xfs_vfs,
 	command_xlog,
@@ -18,6 +19,7 @@ const commandtable_t *commandtable_xfs[] = {
 	&command_xfs_inode,
 	&command_xfs_log_item,
 	&command_xfs_mount,
+	&command_xfs_perag,
 	&command_xfs_trans,
 	&command_xfs_vfs,
 	&command_xlog,
